@@ -1,5 +1,8 @@
-from aiommost import schemas
+import pytest
+
 from aiommost.client import MattermostClient
+from aiommost.users.schemas import User
+from aiommost.errors import BadRequestError
 
 
 async def test_user_created(client: MattermostClient, fake):
@@ -17,16 +20,21 @@ async def test_user_deleted(client: MattermostClient, fake):
     await client.users.delete(user.uid)
 
 
-async def test_get_by_username(client: MattermostClient, create_user):
-    existing_user: schemas.User = await create_user()
+async def test_get_by_username_found(client: MattermostClient, create_user):
+    existing_user: User = await create_user()
 
     user = await client.users.get_by_username(existing_user.username)
     assert user.username == existing_user.username
 
 
+async def test_get_by_username_not_found(fake, client: MattermostClient):
+    with pytest.raises(BadRequestError):
+        await client.users.get_by_username(fake.pystr())
+
+
 async def test_get_by_usernames(client: MattermostClient, create_user):
-    first_user: schemas.User = await create_user()
-    second_user: schemas.User = await create_user()
+    first_user: User = await create_user()
+    second_user: User = await create_user()
 
     users = await client.users.get_by_usernames([first_user.username, second_user.username])
     assert len(users) == 2
